@@ -1,5 +1,5 @@
-def get_ip():
-    return '198.120.0.1'
+def get_ip(host):
+    return host.ip_address()
 
 
 def get_emails():
@@ -8,3 +8,7 @@ def get_emails():
 
 def get_gmail_password():
     return 'email password hacked!'
+
+
+def sabotage():
+    return 'can sabotage your friends internet connection'
