@@ -7,12 +7,6 @@ class Spoon(object):
     def talk(self, message='¡Hola extraño!'):
         print(message)
 
-    def bug(self):
-        if 1 > 2:
-            print("1 es mayor que 2")
-        elif 2 > 1:
-            print("2 es mayor que 1")
-
     def spoon(self):
         print("Spoon")
 
